==> org.jwall.web.audit-0.6.9-sources.jar: org/jwall/web/audit/rules/operators/ConditionLT.java <==
/*
 *  Copyright (C) 2007-2014 Christian Bockermann <chris@jwall.org>
 *
 *  This file is part of the  web-audit  library.
 *
 *  web-audit library is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The  web-audit  library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.jwall.web.audit.rules.operators;

import org.jwall.web.audit.SyntaxException;
import org.jwall.web.audit.rules.Condition;

import com.thoughtworks.xstream.annotations.XStreamAlias;

@XStreamAlias("LT")
public class ConditionLT
    extends AbstractCondition
{
    /** The unique class ID */
    private static final long serialVersionUID = -6217065895397429394L;

    public ConditionLT(String variable, String value) throws SyntaxException
    {
        super(variable, value);
    }
    
    public String getOperator(){
        return Condition.LT;
    }


    /**
     * @see org.jwall.web.audit.rules.Condition#matches(java.lang.String, java.lang.String)
     */
    public boolean matches( String pattern, String input ){
    	if( isNumeric( pattern ) ){
    		try {
    			Double v = new Double( pattern );
    			Double w = new Double( input );
    			int rc = v.compareTo( w );
    			return rc > 0; //(new Double( getValue() ).compareTo( new Double( val ) ) ) < 0;
    		} catch (Exception e) {
    		}
    	}
    	
    	return input.compareTo( pattern ) >= 0;
    }
}

==> org.jwall.web.audit-0.6.10-sources.jar: org/jwall/web/audit/rules/operators/ConditionLT.java <==
/*
 *  Copyright (C) 2007-2014 Christian Bockermann <chris@jwall.org>
 *
 *  This file is part of the  web-audit  library.
 *
 *  web-audit library is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The  web-audit  library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.jwall.web.audit.rules.operators;

import org.jwall.web.audit.SyntaxException;
import org.jwall.web.audit.rules.Condition;

import com.thoughtworks.xstream.annotations.XStreamAlias;

@XStreamAlias("LT")
public class ConditionLT
    extends AbstractCondition
{
    /** The unique class ID */
    private static final long serialVersionUID = -6217065895397429394L;

    public ConditionLT(String variable, String value) throws SyntaxException
    {
        super(variable, value);
    }
    
    public String getOperator(){
        return Condition.LT;
    }


    /**
     * @see org.jwall.web.audit.rules.Condition#matches(java.lang.String, java.lang.String)
     */
    public boolean matches( String pattern, String input ){
    	if( isNumeric( pattern ) ){
    		try {
    			log.debug( "evaluating numeric-lt =>  '{}' @lt '{}'", pattern, input);
    			Double v = new Double( pattern );
    			Double w = new Double( input );
    			int rc = v.compareTo( w );
    			return rc > 0; //(new Double( getValue() ).compareTo( new Double( val ) ) ) < 0;
    		} catch (Exception e) {
    		}
    	}
    	
    	log.debug( "evaluating string-lt =>  '{}' @lt '{}'", pattern, input);
    	return input.compareTo( pattern ) >= 0;
    }
}
